#' Connect and parse UniProt Pathology_Biotech information.
#'
#' The function is work to retrieve Pathology_Biotech data from UniProt for 
#' a list of proteins accessions.For more information about what included in the
#' Pathology_Biotech data see https://www.uniprot.org/help/uniprotkb_column_names.
#'
#' @usage GetPathology_Biotech(ProteinAccList , directorypath = NULL)
#'
#' @param ProteinAccList Vector of UniProt Accession/s
#'
#' @param directorypath path to save excel file containig results returened by the function.
#'
#' @return DataFrame where rows names are the accession
#'      and columns contains the information retrieved from the UniProt
#'
#' @note The function also, Creates a csv file with the retrieved information.
#'
#' @examples Obj <- GetPathology_Biotech("O14520")
#'
#' @export
#'
#' @author Mohmed Soudy and Ali Mostafa


GetPathology_Biotech<- function(ProteinAccList , directorypath = NULL){

  # Pathology_Biotech information to be collected
  columns <- c("comment(ALLERGEN)","comment(BIOTECHNOLOGY)",
               "comment(DISRUPTION PHENOTYPE)","comment(DISEASE)","comment(PHARMACEUTICAL)",
               "comment(TOXIC DOSE)")


  baseUrl <- "http://www.uniprot.org/uniprot/"
  ProteinInfoParsed_total = data.frame()
  for (ProteinAcc in ProteinAccList)
  {
    #to see if Request == 200 or not
    Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))

    #this link return information in tab formate (format = tab)
    #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
    ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",columns)

    RequestUrl <- paste0(baseUrl , ProteinName_url)
    if (Request$status_code == 200){
      # parse the information in DataFrame
      ProteinDataTable <- tryCatch(read.table(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
      if (!is.null(ProteinDataTable))
      {
        ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
        # add Dataframes together if more than one accession
        ProteinInfoParsed_total <- rbind(ProteinInfoParsed_total, ProteinInfoParsed)
      }
    }else {
      HandleBadRequests(Request$status_code)
    }
  }
  if(!is.null(directorypath))
  {
    write.csv(ProteinInfoParsed_total , paste0(directorypath , "/" , "Pathology_Biotech Information.csv"))
  }
  return(ProteinInfoParsed_total)
}
